==> capellambse-0.4.7-py3-none-any.whl: capellambse/model/crosslayer/__init__.py <==
# Copyright 2021 DB Netz AG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Utility classes that are used across all layers.

.. diagram:: [CDB] BaseLayer
"""
from .. import common as c
from . import cs, information


class BaseArchitectureLayer(c.GenericElement):
    """A template architecture layer."""

    _xmltag = "ownedArchitectures"

    data_package = c.ProxyAccessor(information.DataPkg)
    interface_package = c.ProxyAccessor(cs.InterfacePkg)

    all_classes = c.ProxyAccessor(
        information.Class, deep=True, aslist=c.ElementList
    )
    all_collections = c.ProxyAccessor(
        information.Collection, deep=True, aslist=c.ElementList
    )
    all_unions = c.ProxyAccessor(
        information.Union, deep=True, aslist=c.ElementList
    )
    all_enumerations = c.ProxyAccessor(
        information.Enumeration, deep=True, aslist=c.ElementList
    )
    all_complex_values = c.ProxyAccessor(
        information.ComplexValue,
        "org.polarsys.capella.core.data.information.datavalue:ComplexValue",
        deep=True,
        aslist=c.ElementList,
        follow_abstract=False,
    )
    all_interfaces = c.ProxyAccessor(
        cs.Interface, deep=True, aslist=c.ElementList
    )

==> capellambse-0.4.10-py3-none-any.whl: capellambse/model/crosslayer/__init__.py <==
# Copyright 2021 DB Netz AG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Utility classes that are used across all layers.

.. diagram:: [CDB] BaseLayer
"""
from .. import common as c
from . import cs, information


class BaseArchitectureLayer(c.GenericElement):
    """A template architecture layer."""

    _xmltag = "ownedArchitectures"

    data_package = c.ProxyAccessor(information.DataPkg)
    interface_package = c.ProxyAccessor(cs.InterfacePkg)

    all_classes = c.ProxyAccessor(
        information.Class, deep=True, aslist=c.ElementList
    )
    all_collections = c.ProxyAccessor(
        information.Collection, deep=True, aslist=c.ElementList
    )
    all_unions = c.ProxyAccessor(
        information.Union, deep=True, aslist=c.ElementList
    )
    all_enumerations = c.ProxyAccessor(
        information.datatype.Enumeration, deep=True, aslist=c.ElementList
    )
    all_complex_values = c.ProxyAccessor(
        information.datavalue.ComplexValue,
        deep=True,
        aslist=c.ElementList,
        follow_abstract=False,
    )
    all_interfaces = c.ProxyAccessor(
        cs.Interface, deep=True, aslist=c.ElementList
    )
